pub struct Client { /* private fields */ }Expand description
The SSDP Client
Implementations
Sourceimpl Client
impl Client
Sourcepub async fn discover(
&self,
identifier: String,
address: MulticastAddr,
search: String,
) -> Result<(), Box<dyn Error>>
pub async fn discover( &self, identifier: String, address: MulticastAddr, search: String, ) -> Result<(), Box<dyn Error>>
Discover SSDP Services
identifier: The unique Identifier for this Client e.g.uuid:83760048-2d32-4e48-854f-f63a8fa9fd09address: In which scope do you want to scan?search:ssdp:allto find all SSDP Services or custom Service Types to look for
Sourcepub fn get_services(&self) -> Vec<ServiceDescription>
pub fn get_services(&self) -> Vec<ServiceDescription>
Retrieve a list of all Services that answered to our multicast call
Sourcepub fn set_timeout(&mut self, timeout: Duration) -> &Self
pub fn set_timeout(&mut self, timeout: Duration) -> &Self
Changes the timeout