ServiceDescription

Struct ServiceDescription 

pub struct ServiceDescription {
    pub usn_uri: String,
    pub service_type_uri: String,
    pub expiration: u32,
    pub location: String,
}
This Describes the basic data exchanged between Service and crate::client::Client

Usages:

Fields

usn_uri: String

Unique Identifier, often a UUID

upnp:uuid:83760048-2d32-4e48-854f-f63a8fa9fd09
uuid:83760048-2d32-4e48-854f-f63a8fa9fd09
service_type_uri: String

Descriptive name, usually a crate::client::Client searches for this term

upnp:clockradio
ms:wince
my:app
expiration: u32

Cache-Control max age

The time this service usually expires and the crate::client::Client should search for again.

According to RFC 2616 the maximum value is: 31536000

location: String

Location of the Service, should be a valid URL

http://foo.com/bar
https://myapp/service