pub struct ServiceDescription {
pub usn_uri: String,
pub service_type_uri: String,
pub expiration: u32,
pub location: String,
}Expand description
This Describes the basic data exchanged between Service and crate::client::Client
Usages:
- It’s used to create a new Service
- crate::client::Client holds a list of all it could find within the network
Fields
usn_uri: StringUnique Identifier, often a UUID
upnp:uuid:83760048-2d32-4e48-854f-f63a8fa9fd09
uuid:83760048-2d32-4e48-854f-f63a8fa9fd09service_type_uri: StringDescriptive name, usually a crate::client::Client searches for this term
upnp:clockradio
ms:wince
my:appexpiration: u32Cache-Control max age
The time this service usually expires and the crate::client::Client should search for again.
According to RFC 2616 the maximum value is: 31536000
location: StringLocation of the Service, should be a valid URL
http://foo.com/bar
https://myapp/serviceTrait Implementations
Sourceimpl Clone for ServiceDescription
impl Clone for ServiceDescription
Sourcefn clone(&self) -> ServiceDescription
fn clone(&self) -> ServiceDescription
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServiceDescription
impl Debug for ServiceDescription
Sourceimpl PartialEq for ServiceDescription
impl PartialEq for ServiceDescription
impl Eq for ServiceDescription
impl StructuralPartialEq for ServiceDescription